;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "epkg" "20251108.1325"
  "Browse the Emacsmirror package database."
  '((emacs   "28.1")
    (compat  "30.1")
    (closql  "2.3")
    (emacsql "4.3")
    (llama   "1.0"))
  :url "https://github.com/emacscollective/epkg"
  :commit "a4c8dc4e760ff9d0079e25fa9000b06791ed009b"
  :revdesc "a4c8dc4e760f"
  :keywords '("tools")
  :authors '(("Jonas Bernoulli" . "emacs.epkg@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.epkg@jonas.bernoulli.dev")))
